##  How to Model Data Objects for Data Classification
As mentioned above, data object can help you capture the information for the GDPR initiative. In this context, we must identify applications dealing with public, sensitive, restrictive, and confidential information.
In SAP LeanIX, you can capture this information in the data object fact sheet (Public, Sensitive, Restrictive, and Confidential). Then, you can link the data objects with the respective applications.
When you have this model, you can then leverage the Data Flow Diagram to visualize how your data flows from one application to another. This overview is useful to identify which application is using particular information and has the potential to mitigate information leaks.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756fec67a44101484c295744a6ff8ae_LowRes.png)
You can also get a report on the data classification, as shown below. The report lets you easily identify which data classification is applied in your applications.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f89037a44101481b585b7c4d33f23_LowRes.png)
